@@ -3,7 +3,7 @@
 #' Converts time measurements into seconds
 #'
 #' @param T The time value to convert
-#' @param input The unit of time to convert, allowed values are "minutes", "hours", "days".
+#' @param input The unit of time to convert, allowed values are "minutes", "hours", "days", "years".
 #' @export
 #' @return The numeric value in seconds
 #'
@@ -20,5 +20,8 @@ convert2seconds <- function(T, input="minutes") {
   if (input == "days") {
     return(T*60*60*24)
   }
-  stop(paste("Unknown input to convert2seconds:",input))
+  if (input == "years") {
+    return(T*60*60*24*365)
+  }
+  stop(paste("Unknown input to convert2seconds: ",input))
 }
