@@ -1,7 +1,10 @@
 #' @importFrom utils askYesNo install.packages installed.packages
-package.installed <- function(name, method=NULL, repo=NULL) {
+package.installed <- function(name, method=NULL, repo=NULL, askInstall=TRUE) {
   if(name %in% rownames(installed.packages()) == TRUE) {return(TRUE)}
   else {
+    if (askInstall ==FALSE) {
+      return(FALSE)
+    }
     prompt <- askYesNo(paste("Operation requires missing package ",name,". Install now?"))
     if (prompt == FALSE | is.na(prompt)) {
       stop("Missing package not installed.")
@@ -18,4 +21,4 @@ package.installed <- function(name, method=NULL, repo=NULL) {
       }
     }
   }
-}
\ No newline at end of file
+}
