@@ -1,9 +1,5 @@
 context("wavelength")
 
-test_that("warning when no speed given", {
-  expect_warning(wavelength(1), "relying on value for air")
-})
-
 test_that("default to air with good known value", {
   suppressWarnings(expect_equal(wavelength(1), 343))
 })
@@ -17,5 +13,5 @@ test_that("cm calcualtion is correct", {
 })
 
 test_that("error on invalid unit", {
-  expect_error(wavelength(1, speed=300, unit="Farenheit is a moon unit"))
+  expect_error(wavelength(1, speed=300, unit="Fahrenheit is a moon unit"))
 })
